@@ -7,6 +7,7 @@ Created on Mon Jul 26 15:50:36 2021
 import pandas as pd
 from PFAS_SAT_ProcessModels import Inventory
 import matplotlib.pyplot as plt
+import seaborn as sns
 
 
 class MCResults:
@@ -80,8 +81,8 @@ class MCResults:
                              ax=ax)
 
         ax.set_title(title, fontsize=fontsize)
-        ax.set_ylabel(y, fontsize=fontsize)
-        ax.set_xlabel(x, fontsize=fontsize)
+        ax.set_ylabel(str(y).replace("'", ""), fontsize=fontsize)
+        ax.set_xlabel(str(x).replace("'", ""), fontsize=fontsize)
         ax.tick_params(axis='both', which='major', labelsize=fontsize, rotation='auto')
         ax.tick_params(axis='both', which='minor', labelsize=fontsize * 0.9, rotation='auto')
         return ax
@@ -102,15 +103,14 @@ class MCResults:
         index_list = list(self.results_df.columns)
 
         if fig_type == 'hist':
-            bins = kwargs.get('bin') if kwargs.get('bin') else 30
-            self.results_df[self.results_df.columns[index_list.index(param)]].plot(kind=fig_type,
-                                                                                   ax=ax,
-                                                                                   bins=bins)
+            bins = kwargs.get('bins') if kwargs.get('bins') else 30
+            sns.histplot(data=self.results_df[self.results_df.columns[index_list.index(param)]].values,
+                         stat='percent', ax=ax, bins=bins)
+            ax.set_xlabel(param)
         else:
             self.results_df[self.results_df.columns[index_list.index(param)]].plot(kind=fig_type,
                                                                                    ax=ax)
 
-        ax.set_xlabel(param)
         ax.set_title(title, fontsize=fontsize)
         ax.tick_params(axis='both', which='major', labelsize=fontsize, rotation='auto')
         ax.tick_params(axis='both', which='minor', labelsize=fontsize * 0.9, rotation='auto')
